Typography - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Typography

Bootstrap documentation

Typography plays an important role in creating an attractive and clear interface design. Good typography will make the content easy to follow and improve the usability of your website.

## Headings

Use HTML headings to organize content on your website and make the structure clear and user-friendly.

    <h1>H1 Heading</h1>
    <h2>H2 Heading</h2>
    <h3>H3 Heading</h3>
    <h4>H4 Heading</h4>
    <h5>H5 Heading</h5>
    <h6>H6 Heading</h6>

## Paragraphs

Organize longer pieces of text into paragraphs using the `p` tag.

    <p>Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.</p>
    <p>At vero eos et accusam et justo duo dolores et ea rebum.</p>

## Semantic text elements

Use a variety of semantic text elements, depending of how you want to display particular fragments of content.

    <abbr title="Internationalization">I18N</abbr>
    <strong>Bold</strong>
    <cite>Citation</cite>
    <code>Hello World!</code>
    <del>Deleted</del>
    <em>Emphasis</em>
    <i>Italic</i>
    <ins>Inserted</ins>
    <kbd>Ctrl + S</kbd>
    <mark>Highlighted</mark>
    <s>Strikethrough</s
    <samp>Sample</samp>
    Text <sub>Subscripted</sub>
    Text <sup>Superscripted</sup>
    <time>20:00</time>
    <u>Underline</u>
    <var>x</var> = <var>y</var> + 2

## Horizontal rules

Use the `hr` tag to represent a thematic break between paragraphs within one section.

    <hr>

## Horizontal rules with label

You can also add a label to a horizontal rule and align it as you see fit.

    <p>
      Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.
    </p>
    <div class="hr-text">
      <span>Rule text</span>
    </div>
    <p>
      At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
    </p>
    <div class="hr-text hr-text-center">
      <span>Rule text</span>
    </div>
    <p>
      Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.
    </p>
    <div class="hr-text hr-text-end">
      <span>Rule text</span>
    </div>
    <p>
      At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
    </p>

## Optimized for different alphabets

Tabler has been optimized to correctly display content in any language. It supports most Asian, African and Middle Eastern languages.

    <h5>Chinese</h5>
    <p>汉字</p>
    <h5>Japanese</h5>
    <p>日本語の表記体系</p>
    <h5>Korean</h5>
    <p>한글</p>
    <h5>Cyrillic</h5>
    <p>Кириллица</p>
    <h5>Greek</h5>
    <p>Eλληνική</p>
    <h5>Georgian</h5>
    <p>ქართული დამწერლობა</p>
    <h5>Armenian</h5>
    <p>Հայերենի այբուբեն</p>
    <h5>Arabic</h5>
    <p>الحروف العربية</p>
    <h5>Hebrew</h5>
    <p>אלפבית עברי</p>
    <h5>Thai</h5>
    <p>อักษรไทย</p>

## Text transform

Transform the content of components with text capitalization classes.

    <p class="text-lowercase">Lowercased text.</p>
    <p class="text-uppercase">Uppercased text.</p>
    <p class="text-capitalize">Capitalized text.</p>

## Letter spacing

Control the tracking (letter spacing) of an element and make it tight, wide or normal.

    <p class="tracking-tight">Lorem ipsum dolor sit amet. Tight letter spacing.</p>
    <p class="tracking-normal">Lorem ipsum dolor sit amet. Normal letter spacing.</p>
    <p class="tracking-wide">Lorem ipsum dolor sit amet. Wide letter spacing.</p>

## Line height

Control the leading (line height) of an element.

    <p class="lh-1">Lorem ipsum dolor sit amet.<br>
      Dolor sit amet.</p>
    <p class="lh-sm">Lorem ipsum dolor sit amet.<br>
      Dolor sit amet.</p>
    <p class="lh-base">Lorem ipsum dolor sit amet.<br>
      Dolor sit amet.</p>
    <p class="lh-lg">Lorem ipsum dolor sit amet.<br>
      Dolor sit amet.</p>

## Antialiasing

Control the font smoothing of an element.

Use the `.antialiased` utility to render text using subpixel antialiasing or use the `.subpixel-antialiased` utility to remove antialiasing.

    <div class="antialiased">Text with antialiasing</div>
    <div class="subpixel-antialiased">Text without antialiasing</div>

## Markdown elements

If you can’t use the CSS classes you want or if you just want to use HTML tags, use the `.markdown` class in a container. It can handle almost any HTML tag.

    <div class="markdown">
      <h1>Hello World</h1>
      <p>Lorem ipsum<sup><a>[1]</a></sup> dolor sit amet, consectetur adipiscing elit. Nulla accumsan, metus ultrices eleifend gravida, nulla nunc varius lectus, nec rutrum justo nibh eu lectus. Ut vulputate semper dui. Fusce erat odio, sollicitudin vel erat vel, interdum mattis neque. Sub<sub>script</sub> works as well!</p>
      <h2>Second level</h2>
      <p>Curabitur accumsan turpis pharetra <strong>augue tincidunt</strong> blandit. Quisque condimentum maximus mi, sit amet commodo arcu rutrum id. Proin pretium urna vel cursus venenatis. Suspendisse potenti. Etiam mattis sem rhoncus lacus dapibus facilisis. Donec at dignissim dui. Ut et neque nisl.</p>
      <ul>
        <li>In fermentum leo eu lectus mollis, quis dictum mi aliquet.</li>
        <li>Morbi eu nulla lobortis, lobortis est in, fringilla felis.</li>
        <li>Aliquam nec felis in sapien venenatis viverra fermentum nec lectus.</li>
        <li>Ut non enim metus.</li>
      </ul>
    </div>